histomicstk.filters
===========================

.. automodule:: histomicstk.filters
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
    :maxdepth: 1

    edge/gradient filters <histomicstk.filters.edge>
    shape filters <histomicstk.filters.shape>
